@@ -22,7 +22,9 @@ version = os.environ.get('CURRENT_VERSION_ID', '').split('.')[0]
 if (__name__ == 'google.appengine.ext.mapreduce'
     and version != 'ah-builtin-python-bundle'):
   msg = ('You should not use the mapreduce library that is bundled with the'
-         ' SDK. Use the one from'
-         ' https://pypi.python.org/pypi/GoogleAppEngineMapReduce instead.')
+         ' SDK. You can use the PyPi package at'
+         ' https://pypi.python.org/pypi/GoogleAppEngineMapReduce or use the '
+         'source at https://github.com/GoogleCloudPlatform/appengine-mapreduce '
+         'instead.')
   logging.warn(msg)
 
