@@ -9,9 +9,6 @@
 # 3. Class names should not have "map_job" prefix.
 from .input_reader import InputReader
 from .map_job_config import JobConfig
-from .map_job_context import JobContext
-from .map_job_context import ShardContext
-from .map_job_context import SliceContext
 from .map_job_control import Job
 from .mapper import Mapper
 from .output_writer import OutputWriter
