@@ -24,7 +24,10 @@
 import httplib
 import logging
 
-import simplejson
+try:
+  import json
+except ImportError:
+  import simplejson as json
 
 try:
   from mapreduce import pipeline_base
@@ -224,7 +227,7 @@ class JsonHandler(webapp.RequestHandler):
 
     self.response.headers["Content-Type"] = "text/javascript"
     try:
-      output = simplejson.dumps(self.json_response, cls=json_util.JsonEncoder)
+      output = json.dumps(self.json_response, cls=json_util.JsonEncoder)
     # pylint: disable=broad-except
     except Exception, e:
       logging.exception("Could not serialize to JSON")
