@@ -2201,6 +2201,8 @@ class _GoogleCloudStorageInputReader(InputReader):
       will stop at the first directory instead of matching
       all files under the directory. This allows MR to process bucket with
       hundreds of thousands of files.
+    FAIL_ON_MISSING_INPUT: if specified and True, the MR will fail if any of
+      the input files are missing. Missing files will be skipped otherwise.
   """
 
   # Supported parameters
@@ -2208,12 +2210,14 @@ class _GoogleCloudStorageInputReader(InputReader):
   OBJECT_NAMES_PARAM = "objects"
   BUFFER_SIZE_PARAM = "buffer_size"
   DELIMITER_PARAM = "delimiter"
+  FAIL_ON_MISSING_INPUT = "fail_on_missing_input"
 
   # Internal parameters
   _ACCOUNT_ID_PARAM = "account_id"
 
   # Other internal configuration constants
   _JSON_PICKLE = "pickle"
+  _JSON_FAIL_ON_MISSING_INPUT = "fail_on_missing_input"
   _STRING_MAX_FILES_LISTED = 10  # Max files shown in the str representation
 
   # Input reader can also take in start and end filenames and do
@@ -2242,6 +2246,13 @@ class _GoogleCloudStorageInputReader(InputReader):
     self._bucket = None
     self._bucket_iter = None
 
+    # True iff we should fail on missing input (see class doc above). Set to
+    # None in constructor and overwritten in split_input and from_json.
+    # fail_on_missing_input is not parameter of the constructor to avoid
+    # breaking classes inheriting from _GoogleCloudStorageInputReader and
+    # overriding the constructor.
+    self._fail_on_missing_input = None
+
   def _next_file(self):
     """Find next filename.
 
@@ -2344,6 +2355,7 @@ class _GoogleCloudStorageInputReader(InputReader):
     delimiter = reader_spec.get(cls.DELIMITER_PARAM)
     account_id = reader_spec.get(cls._ACCOUNT_ID_PARAM)
     buffer_size = reader_spec.get(cls.BUFFER_SIZE_PARAM)
+    fail_on_missing_input = reader_spec.get(cls.FAIL_ON_MISSING_INPUT)
 
     # Gather the complete list of files (expanding wildcards)
     all_filenames = []
@@ -2361,14 +2373,19 @@ class _GoogleCloudStorageInputReader(InputReader):
     for shard in range(0, mapper_spec.shard_count):
       shard_filenames = all_filenames[shard::mapper_spec.shard_count]
       if shard_filenames:
-        readers.append(cls(
+        reader = cls(
             shard_filenames, buffer_size=buffer_size, _account_id=account_id,
-            delimiter=delimiter))
+            delimiter=delimiter)
+        reader._fail_on_missing_input = fail_on_missing_input
+        readers.append(reader)
     return readers
 
   @classmethod
   def from_json(cls, state):
     obj = pickle.loads(state[cls._JSON_PICKLE])
+    # fail_on_missing_input might not be set - default to False.
+    obj._fail_on_missing_input = state.get(
+        cls._JSON_FAIL_ON_MISSING_INPUT, False)
     if obj._bucket:
       obj._bucket_iter = iter(obj._bucket)
     return obj
@@ -2377,6 +2394,13 @@ class _GoogleCloudStorageInputReader(InputReader):
     before_iter = self._bucket_iter
     self._bucket_iter = None
     try:
+      return {
+          self._JSON_PICKLE: pickle.dumps(self),
+          # self._fail_on_missing_input gets pickled but we save it separately
+          # and override it in from_json to deal with version flipping.
+          self._JSON_FAIL_ON_MISSING_INPUT:
+              getattr(self, "_fail_on_missing_input", False)
+      }
       return {self._JSON_PICKLE: pickle.dumps(self)}
     finally:
       self._bucket_itr = before_iter
@@ -2415,6 +2439,11 @@ class _GoogleCloudStorageInputReader(InputReader):
 
         return handle
       except cloudstorage.NotFoundError:
+        # Fail the job if we're strict on missing input.
+        if getattr(self, "_fail_on_missing_input", False):
+          raise errors.FailJobError(
+              "File missing in GCS, aborting: %s" % filename)
+        # Move on otherwise.
         logging.warning("File %s may have been removed. Skipping file.",
                         filename)
 
