@@ -1,6 +1,5 @@
 #!/usr/bin/env python
-#
-# Copyright 2011 Google Inc.
+# Copyright 2011 Google Inc. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -30,15 +29,17 @@ __all__ = [
     ]
 
 
-from mapreduce.third_party import pipeline
-from mapreduce.third_party.pipeline import common as pipeline_common
-from google.appengine.api import files
+import pipeline
+from pipeline import common as pipeline_common
+from google.appengine.api import app_identity
+from mapreduce import errors
 from mapreduce import input_readers
 from mapreduce import mapper_pipeline
 from mapreduce import model
 from mapreduce import output_writers
 from mapreduce import pipeline_base
 from mapreduce import shuffler
+from mapreduce import util
 
 # pylint: disable=g-bad-name
 # pylint: disable=protected-access
@@ -49,9 +50,9 @@ MapperPipeline = mapper_pipeline.MapperPipeline
 
 ShufflePipeline = shuffler.ShufflePipeline
 
-CleanupPipeline = mapper_pipeline._CleanupPipeline
+CleanupPipeline = shuffler._GCSCleanupPipeline
 
-# For backward compatibilty.
+# For backward compatibility.
 _ReducerReader = input_readers._ReducerReader
 
 
@@ -79,13 +80,17 @@ class MapPipeline(pipeline_base._OutputSlotsMixin,
           input_reader_spec,
           params,
           shards=None):
+    new_params = dict(params or {})
+    # Although we are using all the default settings (and inherited bucket_name)
+    # we still need to define an output_writer dict in order to pass validation.
+    new_params.update({"output_writer": {}})
     yield MapperPipeline(
         job_name + "-map",
         mapper_spec,
         input_reader_spec,
-        output_writer_spec=
-            output_writers.__name__ + ".KeyValueBlobstoreOutputWriter",
-        params=params,
+        output_writer_spec=(output_writers.__name__ +
+                            "._GoogleCloudStorageKeyValueOutputWriter"),
+        params=new_params,
         shards=shards)
 
 
@@ -101,6 +106,7 @@ class ReducePipeline(pipeline_base._OutputSlotsMixin,
     output_writer_spec: specification of output write to use with reduce
       function.
     params: mapper parameters to use as dict.
+    bucket_name: The name of the Google Cloud Storage bucket.
     filenames: list of filenames to reduce.
     combiner_spec: Optional. Specification of a combine function. If not
       supplied, no combine step will take place. The combine function takes a
@@ -120,13 +126,18 @@ class ReducePipeline(pipeline_base._OutputSlotsMixin,
           reducer_spec,
           output_writer_spec,
           params,
+          bucket_name,
           filenames,
           combiner_spec=None,
           shards=None):
+    filenames_only = (
+        util.strip_prefix_from_items("/%s/" % bucket_name, filenames))
     new_params = dict(params or {})
     new_params.update({
-        "files": filenames
-        })
+        "input_reader": {
+            "bucket_name": bucket_name,
+            "objects": filenames_only,
+        }})
     if combiner_spec:
       new_params.update({
           "combiner_spec": combiner_spec,
@@ -149,6 +160,10 @@ class MapreducePipeline(pipeline_base._OutputSlotsMixin,
                         pipeline_base.PipelineBase):
   """Pipeline to execute MapReduce jobs.
 
+  The Shuffle stage uses Google Cloud Storage (GCS). For newly created projects,
+  GCS is activated automatically. To activate GCS follow these instructions:
+  https://cloud.google.com/storage/docs/signup#activate
+
   Args:
     job_name: job name as string.
     mapper_spec: specification of mapper to use.
@@ -168,7 +183,7 @@ class MapreducePipeline(pipeline_base._OutputSlotsMixin,
   Returns:
     result_status: one of model.MapreduceState._RESULTS. Check this to see
       if the job is successful.
-    default: a list of filenames if the mapreduce was sucesssful and
+    default: a list of filenames if the mapreduce was successful and
       was outputting files. An empty list otherwise.
   """
 
@@ -182,18 +197,34 @@ class MapreducePipeline(pipeline_base._OutputSlotsMixin,
           reducer_params=None,
           shards=None,
           combiner_spec=None):
+    # Check that you have a bucket_name set in the mapper_params and set it
+    # to the default if not.
+    if mapper_params.get("bucket_name") is None:
+      try:
+        mapper_params["bucket_name"] = (
+            app_identity.get_default_gcs_bucket_name())
+      except Exception, e:
+        raise errors.Error("Unable to get the GCS default bucket name. "
+                           "Check to see that GCS is properly activated. "
+                           + str(e))
+    if mapper_params["bucket_name"] is None:
+      raise errors.Error("There is no GCS default bucket name. "
+                         "Check to see that GCS is properly activated.")
+    # TODO(user): Check that the bucket is indeed writable.
+
     map_pipeline = yield MapPipeline(job_name,
                                      mapper_spec,
                                      input_reader_spec,
                                      params=mapper_params,
                                      shards=shards)
     shuffler_pipeline = yield ShufflePipeline(
-        job_name, map_pipeline)
+        job_name, mapper_params, map_pipeline)
     reducer_pipeline = yield ReducePipeline(
         job_name,
         reducer_spec,
         output_writer_spec,
         reducer_params,
+        mapper_params["bucket_name"],
         shuffler_pipeline,
         combiner_spec=combiner_spec)
     with pipeline.After(reducer_pipeline):
