@@ -73,7 +73,7 @@ import struct
 
 # Note: this will be scrubbed to google.appengine.api.files import crc32c
 # when mapreduce is pushed to runtime.
-from mapreduce.lib import crc32c
+from mapreduce.third_party import crc32c
 from mapreduce import errors
 
 
